FlopListController class

Inheritance

Constructors

FlopListController()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isAttached bool
no setter
items UnmodifiableListView<FlopListItem>
列表项信息
no setter
position ScrollPosition
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
jumpTo(int index) → void
跳转到指定列表项位置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
updateItems(List<FlopListItem> items) → void
更新列表项信息

Operators

operator ==(Object other) bool
The equality operator.
inherited